@@ -5,7 +5,11 @@ from snowflake.sqlalchemy import URL
 from sqlalchemy import create_engine
 import logging
 logger = logging.getLogger('snowflake.connector',)
-logger.setLevel(logging.warning(msg='what the fucking fuck Shimon are you doing?!'))
+logger.setLevel(logging.warning(msg='what the fucking fuck'))
+ch = logging.FileHandler('python_connector.log')
+ch.setLevel(logging.DEBUG)
+ch.setFormatter(logging.Formatter('%(asctime)s - %(threadName)s %(filename)s:%(lineno)d - %(funcName)s() - %(levelname)s - %(message)s'))
+logger.addHandler(ch)
 
 
 # !conda install -y -c conda-forge pyarrow
